## Notebooks
The following notebooks are intended to provide simplified interfaces into the Fisher information framework. To apply the framework to your own experimental design problems, you can modify the example models in the following [Jupyter](https://jupyter.org) notebooks.

Tutorial notebooks:
* [angle.ipynb](/examples/angle.ipynb) - Angle choice(s) for a simple sample with thin layers.
* [contrast.ipynb](/examples/contrast.ipynb) - Contrast choice(s) for a 1,2-dimyristoyl-sn-glycero-3-phosphocholine (DMPC) bilayer model.
* [simulation.ipynb](/examples/simulation.ipynb) - Simulating an experiment for a simple sample using [refnx](https://refnx.readthedocs.io/en/latest/) and [Refl1D](https://refl1d.readthedocs.io/en/latest/).

Article notebooks:
* [bilayers.ipynb](/examples/bilayers.ipynb) - Generates the lipid bilayer results of the article 
* [kinetics.ipynb](/examples/kinetics.ipynb) - Generates the kinetics results of the article 
* [magnetism.ipynb](/examples/magnetism.ipynb) - Generates the magnetism results of the article.

To run an example, you can call the file from the command line (e.g., ```jupyter notebook angle.py```).
